summaryrefslogtreecommitdiff
path: root/tests/admin_views
diff options
context:
space:
mode:
authorAlexander Gaevsky <sasha@sasha0.ru>2015-12-24 23:32:53 +0200
committerTim Graham <timograham@gmail.com>2015-12-29 19:31:43 -0500
commit69208a5a1c55d42ca0eaffa900be643d9f801089 (patch)
tree6a0ef472b9c7ad89e02e374f7e26fac09c14442c /tests/admin_views
parentdbb0df2a0ec5bee80bee336fc81408efb30b7e47 (diff)
Fixed #25465 -- Restored line breaks conversion in admin readonly fields.
Diffstat (limited to 'tests/admin_views')
-rw-r--r--tests/admin_views/admin.py4
-rw-r--r--tests/admin_views/models.py2
-rw-r--r--tests/admin_views/tests.py18
3 files changed, 21 insertions, 3 deletions
diff --git a/tests/admin_views/admin.py b/tests/admin_views/admin.py
index 5df79675a3..25502dc6af 100644
--- a/tests/admin_views/admin.py
+++ b/tests/admin_views/admin.py
@@ -387,7 +387,7 @@ class LinkInline(admin.TabularInline):
model = Link
extra = 1
- readonly_fields = ("posted", "multiline")
+ readonly_fields = ("posted", "multiline", "readonly_link_content")
def multiline(self, instance):
return "InlineMultiline\ntest\nstring"
@@ -435,7 +435,7 @@ class PostAdmin(admin.ModelAdmin):
readonly_fields = (
'posted', 'awesomeness_level', 'coolness', 'value',
'multiline', 'multiline_html', lambda obj: "foo",
- 'multiline_html_allow_tags',
+ 'multiline_html_allow_tags', 'readonly_content',
)
inlines = [
diff --git a/tests/admin_views/models.py b/tests/admin_views/models.py
index 9a6b63230a..c105c42e4a 100644
--- a/tests/admin_views/models.py
+++ b/tests/admin_views/models.py
@@ -451,6 +451,7 @@ class Link(models.Model):
posted = models.DateField(default=link_posted_default)
url = models.URLField()
post = models.ForeignKey("Post", models.CASCADE)
+ readonly_link_content = models.TextField()
class PrePopulatedPost(models.Model):
@@ -468,6 +469,7 @@ class PrePopulatedSubPost(models.Model):
class Post(models.Model):
title = models.CharField(max_length=100, help_text="Some help text for the title (with unicode ŠĐĆŽćžšđ)")
content = models.TextField(help_text="Some help text for the content (with unicode ŠĐĆŽćžšđ)")
+ readonly_content = models.TextField()
posted = models.DateField(
default=datetime.date.today,
help_text="Some help text for the date (with unicode ŠĐĆŽćžšđ)"
diff --git a/tests/admin_views/tests.py b/tests/admin_views/tests.py
index 61ba8f5aad..9bf0c2dc8e 100644
--- a/tests/admin_views/tests.py
+++ b/tests/admin_views/tests.py
@@ -50,7 +50,7 @@ from .models import (
City, Collector, Color, ComplexSortedPerson, CoverLetter, CustomArticle,
CyclicOne, CyclicTwo, DooHickey, Employee, EmptyModel, ExternalSubscriber,
Fabric, FancyDoodad, FieldOverridePost, FilteredManager, FooAccount,
FoodDelivery, FunkyTag, Gallery, Grommet, Inquisition, Language,
MainPrepopulated, ModelWithStringPrimaryKey, OtherStory, Paper, Parent,
ParentWithDependentChildren, Person, Persona, Picture, Pizza, Plot,
PlotDetails, PluggableSearchPerson, Podcast, Post, PrePopulatedPost, Promo,
@@ -4581,6 +4581,22 @@ class ReadonlyTest(TestCase):
response = self.client.get(reverse('admin:admin_views_post_change', args=(p.pk,)))
self.assertContains(response, "%d amount of cool" % p.pk)
+ @ignore_warnings(category=RemovedInDjango20Warning) # for allow_tags deprecation
+ def test_readonly_text_field(self):
+ p = Post.objects.create(
+ title="Readonly test", content="test",
+ readonly_content='test\r\n\r\ntest\r\n\r\ntest\r\n\r\ntest',
+ )
+ Link.objects.create(
+ url="http://www.djangoproject.com", post=p,
+ readonly_link_content="test\r\nlink",
+ )
+ response = self.client.get(reverse('admin:admin_views_post_change', args=(p.pk,)))
+ # Checking readonly field.
+ self.assertContains(response, 'test<br /><br />test<br /><br />test<br /><br />test')
+ # Checking readonly field in inline.
+ self.assertContains(response, 'test<br />link')
+
def test_readonly_post(self):
data = {
"title": "Django Got Readonly Fields",
@@ -50,7 +50,7 @@ from .models import (
CyclicOne, CyclicTwo, DooHickey, Employee, EmptyModel, ExternalSubscriber,
Fabric, FancyDoodad, FieldOverridePost, FilteredManager, FooAccount,
- FoodDelivery, FunkyTag, Gallery, Grommet, Inquisition, Language,
+ FoodDelivery, FunkyTag, Gallery, Grommet, Inquisition, Language, Link,
MainPrepopulated, ModelWithStringPrimaryKey, OtherStory, Paper, Parent,
ParentWithDependentChildren, Person, Persona, Picture, Pizza, Plot,